==> random_unicode_emoji-2.3.tar.gz: random_unicode_emoji-2.3/README.md <==
# Random Unicode Emoji

[![Python](https://img.shields.io/pypi/pyversions/random-unicode-emoji)](https://pypi.org/project/random-unicode-emoji/)
[![PyPI Version](https://img.shields.io/pypi/v/random-unicode-emoji)](https://pypi.org/project/random-unicode-emoji/)
[![Downloads](https://pepy.tech/badge/random-unicode-emoji)](https://pepy.tech/project/random-unicode-emoji)
[![GitHub Repo stars](https://img.shields.io/github/stars/NicPWNs/random-unicode-emoji)](https://github.com/NicPWNs/random_unicode_emoji/stargazers)
[![Forks](https://img.shields.io/github/forks/NicPWNs/random-unicode-emoji.svg)](https://github.com/NicPWNs/random-unicode-emoji/forks)
[![GitHub Repo size](https://img.shields.io/github/repo-size/NicPWNs/random-unicode-emoji)](https://github.com/NicPWNs/random_unicode_emoji)
[![License](https://img.shields.io/badge/license-MIT-green.svg)](https://github.com/NicPWNs/random_unicode_emoji/blob/main/LICENSE.rst)
[![Open Issues](https://img.shields.io/github/issues/NicPWNs/random-unicode-emoji.svg)](https://github.com/NicPWNs/random-unicode-emoji/issues)
[![Project Status](http://www.repostatus.org/badges/latest/active.svg)](http://www.repostatus.org/#active)

A Python package and function to retrieve a random Unicode emoji. ❤️

> Like this repo? Give it a [⭐ on GitHub!](https://github.com/NicPWNs/random_unicode_emoji)

## Install

```bash
pip install random-unicode-emoji
```

> No dependencies!

## Usage

```py
# Import the Library
from random_unicode_emoji import random_emoji
# Use the Function
print(random_emoji())
# Use Specific Version
print(random_emoji(version="14.0"))
```

## Upgrade

Upgrade to the latest version:

```bash
pip install random-unicode-emoji -U
```

## Unicode

Uses Unicode Standard Emoji from [unicode.org](https://www.unicode.org/Public/emoji/)

### Supported Versions

4.0, 5.0, 11.0, 12.0, 12.1, 13.0, 13.1, 14.0, 15.0, and latest=15.0

> _Uses latest version by default._

## Maintainer

[Nic Jones, (NicPWNs)](https://github.com/NicPWNs)

## References

Originally Inspired by [randomEmoji.py](https://gist.github.com/shello/efa2655e8a7bce52f273)

==> random_unicode_emoji-2.4.tar.gz: random_unicode_emoji-2.4/README.md <==
# Random Unicode Emoji

[![Python](https://img.shields.io/pypi/pyversions/random-unicode-emoji)](https://pypi.org/project/random-unicode-emoji/)
[![PyPI Version](https://img.shields.io/pypi/v/random-unicode-emoji)](https://pypi.org/project/random-unicode-emoji/)
[![Downloads](https://pepy.tech/badge/random-unicode-emoji)](https://pepy.tech/project/random-unicode-emoji)
[![GitHub Repo stars](https://img.shields.io/github/stars/NicPWNs/random-unicode-emoji)](https://github.com/NicPWNs/random_unicode_emoji/stargazers)
[![Forks](https://img.shields.io/github/forks/NicPWNs/random-unicode-emoji.svg)](https://github.com/NicPWNs/random-unicode-emoji/forks)
[![GitHub Repo size](https://img.shields.io/github/repo-size/NicPWNs/random-unicode-emoji)](https://github.com/NicPWNs/random_unicode_emoji)
[![License](https://img.shields.io/badge/license-MIT-green.svg)](https://github.com/NicPWNs/random_unicode_emoji/blob/main/LICENSE.rst)
[![Open Issues](https://img.shields.io/github/issues/NicPWNs/random-unicode-emoji.svg)](https://github.com/NicPWNs/random-unicode-emoji/issues)
[![Project Status](http://www.repostatus.org/badges/latest/active.svg)](http://www.repostatus.org/#active)

A Python package and function to retrieve a random Unicode emoji. ❤️

> Like this repo? Give it a [⭐ on GitHub!](https://github.com/NicPWNs/random_unicode_emoji)

## Install

Install the package:

```bash
pip install random-unicode-emoji
```

> No dependencies!

## Usage

Use the package:

```py
# Import the Library
from random_unicode_emoji import random_emoji
# Use the Function
print(random_emoji())
# Use Specific Version
print(random_emoji(version="15.0"))
```

## Upgrade

Upgrade the package to the version:

```bash
pip install random-unicode-emoji -U
```

## Unicode

Uses Unicode Standard Emoji from [Unicode.org](https://www.unicode.org/Public/emoji/)

### Supported Unicode Versions

4.0, 5.0, 11.0, 12.0, 12.1, 13.0, 13.1, 14.0, 15.0 (latest)

> _Uses latest version by default._

## Maintainer

[Nic Jones, (NicPWNs)](https://github.com/NicPWNs)

## References

Originally Inspired by [randomEmoji.py](https://gist.github.com/shello/efa2655e8a7bce52f273)
